@@ -3,9 +3,11 @@ Main interface for codepipeline service type definitions.
 
 Usage::
 
-    from mypy_boto3.codepipeline.type_defs import AWSSessionCredentialsTypeDef
+    ```python
+    from mypy_boto3_codepipeline.type_defs import AWSSessionCredentialsTypeDef
 
     data: AWSSessionCredentialsTypeDef = {...}
+    ```
 """
 from datetime import datetime
 import sys
